#!/bin/bash

#------------------------Read Me-------------------------
# This Moodifier Daemon Installation script is intended for Raspberry Pi 2 and 3.
# This Moodifier Daemon script will install Moodifier Daemon for the root user.
# Running Moodifier Daemon as root is required for using http port 80 and https port 443.
# The original pi user account must also be intact on the system.
# 
# After running this script you can access Moodifier Daemon by:
# 1) Visiting the ip number of the Raspberry Pi with any web browser on your LAN.
# 2) Visiting http://home.moodifier.net with any web browser on your LAN.
#
# This script will download and install Moodifier Daemon in the /root/MoodifierDaemon directory and start the daemon service.
#
# To uninstall Moodifier Daemon simply delete the following 2 directories:
# /root/MoodifierDaemon
# /root/.MoodifierDaemonPrefs
#
# -Installing and running Moodifier Daemon is done entirely on your own risk-
#--------------------------------------------------------


#---------------------Install Commands-------------------
# 1) First we update the package lists from the repositories.
#    -You can safely skip this if you do not intend to use the Moodifier IP-Alarm features.
sudo apt-get update
#
# 2) Moodifier Daemon Alarm IP-camera video recording relies on vlc, so we install vlc prior to Moodifier Daemon.
#    -You can safely skip this if you do not intend to use the Moodifier IP-Alarm features.
sudo apt-get install vlc
#
# 3) Moodifier Daemons optional speech feedback relies on espeak, so we install espeak prior to Moodifier Daemon.
#    -You can safely skip this if you do not intend to use the Moodifier IP-Alarm features.
sudo apt-get install espeak
#
# 4) First we download MoodifierDaemon.zip
sudo curl -o /root/MoodifierDaemon.zip https://www.barsark.com/MoodifierDaemon/rpi/MoodifierDaemon.zip
#
# 5) Then we extract MoodifierDaemon.zip to /root/MoodifierDaemon
sudo unzip -o /root/MoodifierDaemon.zip -d /root/
#
# 6) Then we start Moodifier Daemon on http port 80 (default). You can activate https on port 443 once Moodifier has started.
sudo /root/MoodifierDaemon/MoodifierDaemon -Port=80 --SecurePort=4433
#--------------------End Install Commands----------------


#-------------------AutoStart and Monitor----------------
# After installing Moodifier Daemon we set up a cronjob to auto start and monitor it.
#
# We start Moodifier Daemon at reboot/startup.
croncmd='@reboot ~/.MoodifierDaemonPrefs/CheckMoodifierDaemon.sh > /dev/null 2>&1'
sudo crontab -l | grep -i -v -F "$croncmd" | { cat; echo "$croncmd"; } | sudo crontab -
#
# We check Moodifier Daemon state and functionality every 5 minutes, will restarts if not working properly.
croncmd='*/5 * * * * ~/.MoodifierDaemonPrefs/CheckMoodifierDaemon.sh > /dev/null 2>&1'
sudo crontab -l | grep -i -v -F "$croncmd" | { cat; echo "$croncmd"; } | sudo crontab -
#
# You can edit or remove the cron jobs with the command
#sudo crontab -e
#----------------End AutoStart and Monitor---------------
